@@ -226,27 +226,27 @@ render(struct search_response *r)
 			"<tr>\n"
 			"\t<td align=\"left\" class=\"nowrap\" nowrap>\n");
 		if (curpage > 1) {
-			OUT("\t\t<a href=\"?q=");
+			OUT("\t\t<!--<a href=\"?q=");
 			xmlencode(search);
 			OUT("&amp;page=");
 			snprintf(tmp, sizeof(tmp), "%d", curpage - 1);
 			xmlencode(tmp);
 			OUT("&amp;o=");
 			xmlencode(order);
-			OUT("\" rel=\"prev\" accesskey=\"p\">&larr; prev</a>\n");
+			OUT("\" rel=\"prev\" accesskey=\"p\">&larr; prev</a>-->\n");
 		}
 		OUT(
 			"\t</td>\n\t<td></td>\n"
 			"\t<td align=\"right\" class=\"a-r nowrap\" nowrap>\n");
 
-		OUT("\t\t<a href=\"?q=");
+		OUT("\t\t<!--<a href=\"?q=");
 		xmlencode(search);
 		OUT("&amp;page=");
 		snprintf(tmp, sizeof(tmp), "%d", curpage + 1);
 		xmlencode(tmp);
 		OUT("&amp;o=");
 		xmlencode(order);
-		OUT("\" rel=\"next\" accesskey=\"n\">next &rarr;</a>\n"
+		OUT("\" rel=\"next\" accesskey=\"n\">next &rarr;</a>-->\n"
 		    "\t</td>\n"
 		    "</tr>\n"
 		    "</tfoot>\n"
