@@ -28,21 +28,21 @@ request_search(const char *s, const char *page, const char *order)
 
 	snprintf(path, sizeof(path), "/results?search_query=%s", s);
 
+	/* NOTE: pagination doesn't work at the moment:
+	   this parameter is not supported anymore by Youtube */
 	if (page[0]) {
 		strlcat(path, "&page=", sizeof(path));
 		strlcat(path, page, sizeof(path));
 	}
 
-	if (order[0]) {
-		strlcat(path, "&search_sort=", sizeof(path));
+	if (order[0] && strcmp(order, "relevance")) {
+		strlcat(path, "&sp=", sizeof(path));
 		if (!strcmp(order, "date"))
-			strlcat(path, "video_date_uploaded", sizeof(path));
-		else if (!strcmp(order, "relevance"))
-			strlcat(path, "video_relevance", sizeof(path));
+			strlcat(path, "CAI%3D", sizeof(path));
 		else if (!strcmp(order, "views"))
-			strlcat(path, "video_view_count", sizeof(path));
+			strlcat(path, "CAM%3D", sizeof(path));
 		else if (!strcmp(order, "rating"))
-			strlcat(path, "video_avg_rating", sizeof(path));
+			strlcat(path, "CAE%3D", sizeof(path));
 	}
 
 	/* check if request is too long (truncation) */
@@ -90,9 +90,9 @@ processnode(struct json_node *nodes, size_t depth, const char *value,
 	/* new item, structures can be very deep, just check the end for:
 	   (items|contents)[].videoRenderer objects */
 	if (depth >= 3 &&
-	    nodes[depth - 3].type == TYPE_ARRAY &&
-	    nodes[depth - 2].type == TYPE_OBJECT &&
-	    nodes[depth - 1].type == TYPE_OBJECT &&
+	    nodes[depth - 3].type == JSON_TYPE_ARRAY &&
+	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 1].type == JSON_TYPE_OBJECT &&
 	    (!strcmp(nodes[depth - 3].name, "items") ||
 	     !strcmp(nodes[depth - 3].name, "contents")) &&
 	    !strcmp(nodes[depth - 1].name, "videoRenderer")) {
@@ -105,10 +105,10 @@ processnode(struct json_node *nodes, size_t depth, const char *value,
 	item = &(r->items[r->nitems - 1]);
 
 	if (depth >= 4 &&
-	    nodes[depth - 4].type == TYPE_ARRAY &&
-	    nodes[depth - 3].type == TYPE_OBJECT &&
-	    nodes[depth - 2].type == TYPE_OBJECT &&
-	    nodes[depth - 1].type == TYPE_STRING &&
+	    nodes[depth - 4].type == JSON_TYPE_ARRAY &&
+	    nodes[depth - 3].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 1].type == JSON_TYPE_STRING &&
 	    (!strcmp(nodes[depth - 4].name, "items") ||
 	     !strcmp(nodes[depth - 4].name, "contents")) &&
 	    !strcmp(nodes[depth - 2].name, "videoRenderer") &&
@@ -117,13 +117,13 @@ processnode(struct json_node *nodes, size_t depth, const char *value,
 	}
 
 	if (depth >= 7 &&
-	    nodes[depth - 7].type == TYPE_ARRAY &&
-	    nodes[depth - 6].type == TYPE_OBJECT &&
-	    nodes[depth - 5].type == TYPE_OBJECT &&
-	    nodes[depth - 4].type == TYPE_OBJECT &&
-	    nodes[depth - 3].type == TYPE_ARRAY &&
-	    nodes[depth - 2].type == TYPE_OBJECT &&
-	    nodes[depth - 1].type == TYPE_STRING &&
+	    nodes[depth - 7].type == JSON_TYPE_ARRAY &&
+	    nodes[depth - 6].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 5].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 4].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 3].type == JSON_TYPE_ARRAY &&
+	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 1].type == JSON_TYPE_STRING &&
 	    (!strcmp(nodes[depth - 7].name, "items") ||
 	     !strcmp(nodes[depth - 7].name, "contents")) &&
 	    !strcmp(nodes[depth - 5].name, "videoRenderer") &&
@@ -135,11 +135,11 @@ processnode(struct json_node *nodes, size_t depth, const char *value,
 	}
 
 	if (depth >= 5 &&
-	    nodes[depth - 5].type == TYPE_ARRAY &&
-	    nodes[depth - 4].type == TYPE_OBJECT &&
-	    nodes[depth - 3].type == TYPE_OBJECT &&
-	    nodes[depth - 2].type == TYPE_OBJECT &&
-	    nodes[depth - 1].type == TYPE_STRING &&
+	    nodes[depth - 5].type == JSON_TYPE_ARRAY &&
+	    nodes[depth - 4].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 3].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 1].type == JSON_TYPE_STRING &&
 	    (!strcmp(nodes[depth - 5].name, "items") ||
 	     !strcmp(nodes[depth - 5].name, "contents")) &&
 	    !strcmp(nodes[depth - 3].name, "videoRenderer") &&
@@ -157,15 +157,15 @@ processnode(struct json_node *nodes, size_t depth, const char *value,
 	}
 
 	if (depth >= 9 &&
-	    nodes[depth - 9].type == TYPE_ARRAY &&
-	    nodes[depth - 8].type == TYPE_OBJECT &&
-	    nodes[depth - 7].type == TYPE_OBJECT &&
-	    nodes[depth - 6].type == TYPE_OBJECT &&
-	    nodes[depth - 5].type == TYPE_ARRAY &&
-	    nodes[depth - 4].type == TYPE_OBJECT &&
-	    nodes[depth - 3].type == TYPE_OBJECT &&
-	    nodes[depth - 2].type == TYPE_OBJECT &&
-	    nodes[depth - 1].type == TYPE_STRING &&
+	    nodes[depth - 9].type == JSON_TYPE_ARRAY &&
+	    nodes[depth - 8].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 7].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 6].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 5].type == JSON_TYPE_ARRAY &&
+	    nodes[depth - 4].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 3].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 1].type == JSON_TYPE_STRING &&
 	    (!strcmp(nodes[depth - 9].name, "items") ||
 	     !strcmp(nodes[depth - 9].name, "contents")) &&
 	    !strcmp(nodes[depth - 7].name, "videoRenderer") &&
@@ -179,13 +179,13 @@ processnode(struct json_node *nodes, size_t depth, const char *value,
 	}
 
 	if (depth >= 7 &&
-	    nodes[depth - 7].type == TYPE_ARRAY &&
-	    nodes[depth - 6].type == TYPE_OBJECT &&
-	    nodes[depth - 5].type == TYPE_OBJECT &&
-	    nodes[depth - 4].type == TYPE_OBJECT &&
-	    nodes[depth - 3].type == TYPE_ARRAY &&
-	    nodes[depth - 2].type == TYPE_OBJECT &&
-	    nodes[depth - 1].type == TYPE_STRING &&
+	    nodes[depth - 7].type == JSON_TYPE_ARRAY &&
+	    nodes[depth - 6].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 5].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 4].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 3].type == JSON_TYPE_ARRAY &&
+	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 1].type == JSON_TYPE_STRING &&
 	    (!strcmp(nodes[depth - 7].name, "items") ||
 	     !strcmp(nodes[depth - 7].name, "contents")) &&
 	    !strcmp(nodes[depth - 5].name, "videoRenderer") &&
